jdk/test/java/net/Authenticator/B4962064.java
changeset 13788 3f38e525f30a
parent 5506 202f599c92aa
child 14342 8435a30053c1
--- a/jdk/test/java/net/Authenticator/B4962064.java	Fri Sep 07 14:00:31 2012 +0100
+++ b/jdk/test/java/net/Authenticator/B4962064.java	Fri Sep 07 15:30:17 2012 +0100
@@ -25,7 +25,7 @@
  * @test
  * @bug 4962064
  * @library ../../../sun/net/www/httptest/
  * @build HttpCallback HttpServer ClosedChannelList HttpTransaction
  * @run main/othervm B4962064
  * @summary Extend Authenticator to provide access to request URI and server/proxy
  */
@@ -85,12 +85,12 @@
         is.close();
     }
 
-    static HttpServer server;
+    static TestHttpServer server;
     static URL urlsave;
 
     public static void main (String[] args) throws Exception {
         try {
-            server = new HttpServer (new B4962064(), 1, 10, 0);
+            server = new TestHttpServer (new B4962064(), 1, 10, 0);
             int port = server.getLocalPort();
             System.setProperty ("http.proxyHost", "localhost");
             System.setProperty ("http.proxyPort", Integer.toString (port));
@@ -25,7 +25,7 @@
  * @bug 4962064
  * @library ../../../sun/net/www/httptest/
- * @build HttpCallback HttpServer ClosedChannelList HttpTransaction
+ * @build HttpCallback TestHttpServer ClosedChannelList HttpTransaction
  * @run main/othervm B4962064
  * @summary Extend Authenticator to provide access to request URI and server/proxy